#
# spec file for package python-line_profiler
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-line_profiler
Version:        4.2.0
Release:        1.1
Summary:        Line-by-line profiler
License:        BSD-3-Clause
URL:            https://github.com/pyutils/line_profiler
Source:         https://files.pythonhosted.org/packages/source/l/line_profiler/line_profiler-%{version}.tar.gz
BuildRequires:  %{python_module Cython}
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module ipython}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module scikit-build}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module ubelt}
BuildRequires:  %{python_module wheel}
BuildRequires:  cmake
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  ninja
BuildRequires:  python-rpm-macros
Requires:       python-ipython
Requires(post): update-alternatives
Requires(postun): update-alternatives
%python_subpackages

%description
line_profiler will profile the time individual lines of code take to execute.
The profiler is implemented in C via Cython in order to reduce the overhead of
profiling.

Also included is the script kernprof.py which can be used to conveniently
profile Python applications and scripts either with line_profiler or with the
function-level profiling tools in the Python standard library.

%prep
%autosetup -p1 -n line_profiler-%{version}

%build
export CFLAGS="%{optflags} -fno-strict-aliasing"
# remove shebangs
sed -i '1{/env python/d}' line_profiler/line_profiler.py kernprof.py
%pyproject_wheel

%install
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/kernprof
%python_compileall
%python_expand %fdupes %{buildroot}%{$python_sitearch}

%post
%python_install_alternative kernprof

%postun
%python_uninstall_alternative kernprof

%check
# test_cli needs ubelt, which we don't have and which is needed just for tests
# test_assumed_noop removed upstream, stop skipping it with 4.2.0.
%pytest_arch -k "not (test_cli or test_assumed_noop)" tests

%files %{python_files}
%doc README.rst
%license LICENSE.txt LICENSE_Python.txt
%python_alternative %{_bindir}/kernprof
%{python_sitearch}/line_profiler
%{python_sitearch}/line_profiler-%{version}.dist-info
%{python_sitearch}/kernprof.py
%pycache_only %{python_sitearch}/__pycache__/kernprof.*.pyc

%changelog
* Sun May  4 2025 Dirk Müller <dmueller@suse.com>
- update to 4.2.0:
  * FIX: Fix issue with auto-profile of editable installs #279
  * FIX: Lookup OP-codes instead of hard coding them #284
  * CHANGE: Drop support for Python 3.6 and Python 3.7
  * ENH: Add support for Python 3.13
* Tue Nov 26 2024 Steve Kowalik <steven.kowalik@suse.com>
- Update to 4.1.3:
  * FIX: duration summary now respects the stripzeros argument.
  * FIX: minor test fixes.
  * ENH: building osx wheels for x86 and arm64.
  * ENH: documentation improvements.
  * Invoke subshell with the current python interpreter
  * Respect stripzeros in summary report
  * Normalize path before comparison
- Switch to pyproject macros.
- Drop patch use-sys-executable-python.patch, included upstream.
* Wed Mar 13 2024 Dirk Müller <dmueller@suse.com>
- skip python 3.9 build
* Tue Dec  5 2023 Dirk Müller <dmueller@suse.com>
- update to 4.1.2:
  * ENH: Add support for Python 3.12 #246
  * ENH: Add osx universal2 and arm64 wheels
  * ENH: Fix issue with integer overflow on 32 bit systems
  * FIX: ``get_stats`` is no longer slowed down when profiling
    many code sections #236
  * FIX: skipzeros now checks for zero hits instead of zero time
  * FIX: Fixed errors in Python 3.11 with duplicate functions.
  * FIX: ``show_text`` now increases column sizes or switches to
    scientific notation to maintain alignment
  * ENH: ``show_text`` now has new options: sort and summarize
  * ENH: Added new CLI arguments ``-srm`` to ``line_profiler`` to
    control sorting, rich printing, and summary printing.
  * ENH: New global ``profile`` function that can be enabled by
    ``--profile`` or ``LINE_PROFILE=1``.
  * ENH: New auto-profile feature in ``kernprof`` that will
    profile all functions in specified modules.
  * ENH: Kernprof now outputs instructions on how to view
    results.
  * ENH: Added readthedocs integration:
    https://kernprof.readthedocs.io/en/latest/index.html
- Add patch use-sys-executable-python.patch:
  * Use sys.executable, rather than 'python'.
* Sun Aug 13 2023 Dirk Müller <dmueller@suse.com>
- restrict to older Cython release
* Sun Mar 26 2023 Dirk Müller <dmueller@suse.com>
- update to 4.0.3:
  * FIX: Stop requiring bleeding-edge Cython unless necesasry
    (for Python 3.12).  #206
* Mon Feb 20 2023 Steve Kowalik <steven.kowalik@suse.com>
- Update to 4.0.2:
  * FIX: AttributeError on certain methods. #191
  * FIX: Profiling classmethods works again. #183
  * ENH: Python 3.11 is now supported.
  * ENH: Profiling overhead is now drastically smaller, thanks to
    reimplementing almost all of the tracing callback in C++.
  * ENH: Added the ``-i <# of seconds>`` option to the ``kernprof`` script.
  * CHANGE: Cython's native cythonize function is now used to compile the
    project, instead of scikit-build's convoluted process.
  * CHANGE: Due to optimizations done while reimplementing the callback in
    C++, the profiler's code_map and last_time attributes now are indexed by
    a hash of the code block's bytecode and its line number.
  * FIX: filepath test in is_ipython_kernel_cell for Windows #161
  * ADD: setup.py now checks LINE_PROFILER_BUILD_METHOD to determine how
    to build binaries
  * ADD: LineProfiler.add_function warns if an added function has a
    __wrapped__ attribute
- Due to build system change, massively simplify %%build.
* Thu Sep 29 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to Version 3.5.2
  * FIX: filepath test in is_ipython_kernel_cell for Windows #161
  * ADD: setup.py now checks LINE_PROFILER_BUILD_METHOD to determine how to build binaries
  * ADD: LineProfiler.add_function warns if an added function has a __wrapped__ attribute
- Update to Version 3.5.1
  * FIX: #19 line profiler now works on async functions again
- Update to Version 3.5.0
  * FIX: #109 kernprof fails to write to stdout if stdout was replaced
  * FIX: Fixes max of an empty sequence error #118
  * Make IPython optional
  * FIX: #100 Exception raise ZeroDivisionError
* Fri Jan  7 2022 Ben Greiner <code@bnavigator.de>
- Update to 3.4.0
  * Drop support for Python <= 3.5.x
  * FIX: #104 issue with new IPython kernels
  * Wheels for musllinux are now included
  * FIX: Fix bug where lines were not displayed in Jupyter>=6.0 via
    [#93]
- Release 3.3.1
  * CHANGE: moving forward, new pypi releases will be signed with
    the GPG key 2A290272C174D28EA9CA48E9D7224DAF0347B114 for
    PyUtils-CI openpyutils@gmail.com. For reference, older versions
    were signed with either
    262A1DF005BE5D2D5210237C85CD61514641325F or
    1636DAF294BA22B89DBB354374F166CFA2F39C18.
- Release 3.2.5
  * Include c source files in manifest (#74)
- Fix IPython requirements
- Fix platform install dir
* Thu Apr 22 2021 Markéta Machová <mmachova@suse.com>
- update to 3.1.0
  * Restructure into package
  * fix Python 3.9
* Wed Jan  2 2019 Tomáš Chvátal <tchvatal@suse.com>
- Regenerate cython files to fix build under python 3.7
* Mon Oct 29 2018 Todd R <toddrme2178@gmail.com>
- It doesn't have a direct dependency on prompt_toolkit.
* Thu Jul 19 2018 mcepl@suse.com
- Switch off tests (they are broken,
  https://github.com/rkern/line_profiler/issues/128)
* Thu May 10 2018 toddrme2178@gmail.com
- Set minimum python3 version
* Thu May  3 2018 toddrme2178@gmail.com
- Use %%license tag
* Thu Apr 19 2018 toddrme2178@gmail.com
- Update to version 2.1.2
  * ENH: Add support for Python 3.5 coroutines
  * ENH: Documentation updates
  * ENH: CI for most recent Python versions (3.5, 3.6, 3.6-dev, 3.7-dev, nightly)
  * ENH: Add timer unit argument for output time granularity spec
* Tue Aug 29 2017 toddrme2178@gmail.com
- Update to version 2.0
  * Added support for IPython 5.0+, removed support for IPython <=0.12
- Update to version 1.1
  * Read source files as bytes.
- Implement single-spec version
* Tue Nov 11 2014 toddrme2178@gmail.com
- Implement update-alternatives
- Implement unit tests
* Thu Oct  2 2014 termim@gmail.com
- Update to 1.0
  * `kernprof.py` is now installed as `kernprof`.
  * Python 3 support. Thanks to the long-suffering Mikhail Korobov for
    being patient.
  * Dropped 2.6 as it was too annoying.
  * The `stripzeros` and `add_module` options. Thanks to Erik Tollerud
    for contributing it.
  * Support for IPython cell blocks. Thanks to Michael Forbes for adding
    this feature.
  * Better warnings when building without Cython. Thanks to David
    Cournapeau for spotting this.
* Mon Mar 10 2014 toddrme2178@gmail.com
- Update to 1.0b3
  * Profile generators.
  * Update for compatibility with newer versions of Cython.
    Thanks to Ondrej Certik for spotting the bug.
  * Update IPython compatibility for 0.11+. Thanks to Yaroslav
    Halchenko and others for providing the updated imports.
* Fri Jul  1 2011 saschpe@suse.de
- Initial version
